from __future__ import unicode_literals

from pipedash.processor import BaseProcessor


class CssminCompressor(BaseProcessor):

    input_extension = 'css'
    output_extension = 'css'
    command = ['cssmin']
